Module errors

Module errors 

A collection of errors specific to this crate’s types that can occur when using them.

Structs

ParseIntError
The error type that is returned when parsing an integer from an invalid source.
TryFromIntError
The error type that is returned when a failed conversion from an integer occurs.