pub struct ParseIntError { /* private fields */ }Expand description
The error type that is returned when parsing an integer from an invalid source.
This error can occur when the from_str_radix or FromStr::from_str methods of e.g. BUint are called with an invalid input string.
Implementations
Sourceimpl ParseIntError
impl ParseIntError
Sourcepub const fn kind(&self) -> &IntErrorKind
pub const fn kind(&self) -> &IntErrorKind
Returns the enum IntErrorKind, which shows the reason that the parsing input was invalid.